// Pingus - A free Lemmings clone
// Copyright (C) 1999 Ingo Ruhnke <grumbel@gmx.de>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#include <ClanLib/clanlib.h>
#include <ClanLib/clanlayer2.h>
#include <assert.h>

#include "Background.hh"
#include "globals.hh"

Background::Background(const char* bg_name)
{
  bg_surface = CL_Res_Surface::load(bg_name, *resource());
  
  if (!bg_surface) {
    cerr << bg_name << ": Could not load file" << endl;
    exit(EXIT_FAILURE);
  }
  scroll = 0;
  scroll.set_speed(0);
  scroll.set_size(bg_surface->get_width() - 1);
}

Background::~Background()
{
  delete bg_surface;
}

void
Background::draw()
{
  assert(bg_surface);

  for(int y=0; y <= CL_Display::get_height(); y += bg_surface->get_height())
    for(int x=0; x < CL_Display::get_width(); x += bg_surface->get_width())
      bg_surface->put_screen(x, y);
}

void
Background::draw_offset(int x_of, int y_of, double s = 1.0)
{
  ++scroll;
  x_of -= (int)(scroll * s);
  assert(bg_surface);
  // BUG: This function works, but I don't know why =?^)
  if (s == 1.0) {
    for(int y=(y_of/2); y < CL_Display::get_height()- 54; y += bg_surface->get_height())
      for(int x=(x_of/2); x < CL_Display::get_width(); x += bg_surface->get_width())
	bg_surface->put_screen(x, y);
  } else {
    for(int y=(y_of/2); y < CL_Display::get_height()- 54; y += (int)(bg_surface->get_height() * s))
      for(int x=(x_of/2); x < CL_Display::get_width(); x += (int)(bg_surface->get_width() * s))
	bg_surface->put_screen(x, y,
			       (int)(bg_surface->get_width() * s),
			       (int)(bg_surface->get_height() * s)
			       );
  }
}

/* EOF */
