// Pingus - A free Lemmings clone
// Copyright (C) 1999 Ingo Ruhnke <grumbel@gmx.de>

// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.

// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#include <iostream>
#include <fstream>
#include <cstdio>
#include <cstdlib>
#include <ClanLib/clanlib.h>

#include "algo.hh"
#include "ColMap.hh"
#include "globals.hh"

ColMap::ColMap()
{
  init = false;
}

ColMap::ColMap(unsigned char* b, int w, int h)
{
  init = true;
  colmap = b;
  width = w;
  height = h;
}

ColMap::~ColMap()
{
  // Bug: This SIGSEGV
  //  for(int i=0; i<width; ++i) {
  //    delete[] ColMap::colmap[i];
  //  }
  // delete[] ColMap::colmap;
}

// BUG: This complete function reads from a text file, it should read
// from a png file instead.
int
ColMap::load(const char* filename)
{
  int start_time = CL_System::get_time();
  init = 1;

  ifstream in(filename);

  if (!in) {
    perror(filename);
    exit(EXIT_FAILURE);
  }

  width = 10;
  height = 10;

  in >> width;
  in >> height;

  // allocate the memory for the colmap
  colmap = new unsigned char[width * height];

  // load the colmap from file to memory
  int temp;

  for(int y=0; y < height; ++y) 
    for(int x=0; x < width; ++x) {
      in >> temp;
      colmap[x+y*width] = temp;
      //      cout <<  (int)colmap[x+y*width] << " ";
    }
  
  if (verbose) {
    cout << "ColMap::load required: " 
	 << CL_System::get_time() - start_time 
	 << " milisec" << endl;
  }

  return true;
}

int
ColMap::getpixel(int x, int y)
{
  if (!init) {
    cout << "NOT INIT" << endl;
    exit(EXIT_FAILURE);
  }

  if (x >= 0 && x < width && y >= 0 && y < height) {
    return colmap[x+y*width];
  } else {
    return nothing; 
  }
}

void
ColMap::remove(int x, int y)
{
  //  for(int x = x1 - 15; x < x1 + 15; ++x)
  if (x > 0 && x < width
      && y > 0 && y < height)
    colmap[x+y*width] = air;
  else
    if (verbose > 2)
      cout << "ColMap: remove: Out of map" << endl;
  
}

/* EOF */
