// Pingus - A free Lemmings clone
// Copyright (C) 1999 Ingo Ruhnke <grumbel@gmx.de>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#include <cassert>

#include "Exit.hh"
#include "actions/pingu_actions.hh"

CL_Surface* Exit::surface;

Exit::Exit(int x, int y)
{
  x_pos = x;
  y_pos = y;
}

Exit::Exit(exit_data data)
{
  x_pos = data.x_pos;
  y_pos = data.y_pos;
}

void 
Exit::catch_pingu(Pingu* pingu)
{
  const int range = 3;

  if (pingu->get_x() > x_pos-1 && pingu->get_x() < x_pos+1 &&
      pingu->get_y() > y_pos-range && pingu->get_y() < y_pos+range) 
    {
      if (pingu->get_status() != exited)
	pingu->set_action(new Exiter);
    }
}

/*void
Exit::draw()
{
  assert(surface);
  surface->put_screen(x_pos-32, y_pos-64);
  }*/

void
Exit::draw_offset(int x, int y, double s = 1.0)
{
  assert(surface);
  surface->put_screen((int)((x_pos + x - 32) * s), (int)((y_pos + y - 64) * s),
		      (int)(surface->get_width() * s), (int)(surface->get_height() * s));
}

void 
Exit::load_data()
{
  surface = CL_Res_Surface::load("Game/exit", *resource());
}

/* EOF */
