// Pingus - A free Lemmings clone
// Copyright (C) 1999 Ingo Ruhnke <grumbel@gmx.de>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#include <dirent.h>
#include <fnmatch.h>
#include <ClanLib/clanlib.h>
#include "globals.hh"
#include "FileSelector.hh"

FileSelector::FileSelector()
{
  cerr << "FileSelector: Grabbing resources" << endl;
  font = CL_Res_Font::load("Fonts/font",*resource());
}

string
FileSelector::select(string pathname, string pattern)
{
  string filename;

  CL_Display::fill_rect(200, 100, 440, 380,
			0.0, 0.0, 0.0, 0.5);
  CL_Display::flip_display();
  CL_Display::fill_rect(200, 100, 440, 380,
			0.0, 0.0, 0.0, 0.5);


  FileSelector::readdir(pathname, pattern);
  FileSelector::draw();

  filename = FileSelector::select_file();

  if (filename == "")
    return "";

  return pathname + filename;
}

string
FileSelector::select_file(void)
{
  int file_index = 0;
  int temp_index = -1;

  while(!CL_Mouse::left_pressed()) {
    CL_System::keep_alive();

    if (CL_Keyboard::get_keycode(CL_Keyboard::KEY_ESCAPE))
      return "";

    if (temp_index != file_index) {
      //      draw(file_index);
      temp_index = file_index;
    }

    file_index = (CL_Mouse::get_y() - 200) / 20;
    
    if (file_index < 0)
      file_index = 0;
    
    if (file_index >= directory.size()) 
      file_index = directory.size() - 1;
  }
  return directory[file_index];
}

void
FileSelector::readdir(string pathname, string pattern)
{
  DIR* dp;
  dirent* de;

  dp = opendir(pathname.c_str());
  
  if (!dp) {
    perror(pathname.c_str());
    exit(EXIT_FAILURE);
  }

  while ((de = ::readdir(dp)) != NULL) {
    if (fnmatch(pattern.c_str(), de->d_name, FNM_PATHNAME) == 0)
      directory.push_back(de->d_name);
  } // BUG, errors aren't checked
  closedir(dp);
}

void
FileSelector::draw(int highlight)
{
  for(unsigned int i=0; i < directory.size(); ++i) {
    font->print_center(320,20*i + 200, directory[i].c_str());
  }
  CL_Display::flip_display();
}

/* EOF */
