// Pingus - A free Lemmings clone
// Copyright (C) 1999 Ingo Ruhnke <grumbel@gmx.de>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#include <ClanLib/clanlib.h>
#include "GroundSurfaceProvider.hh"

GroundSurfaceProvider::GroundSurfaceProvider()
{
  buffer = NULL;
  lock_refs = 0;
  width = 320;
  height = 240;
}

GroundSurfaceProvider::GroundSurfaceProvider(int w, int h)
{
  buffer = NULL;
  lock_refs = 0;
  width = w;
  height = h;

  // Creating Ground Surface
  int y_h = get_height() / 2;

  buffer = new unsigned char[get_pitch()*get_height()];
  
  for (int x=0; x<width; x++, y_h += rand()%3 - 1) {
    for (int y=y_h; y < height; y++) {
      buffer[(x+y*width)*4 + 0] = 255; // alpha component of pixel
      buffer[(x+y*width)*4 + 1] =   y - y_h; // blue component
      buffer[(x+y*width)*4 + 2] =   0; // green component
      buffer[(x+y*width)*4 + 3] =   0; // red component
    }
  }
}

GroundSurfaceProvider::~GroundSurfaceProvider()
{
  delete[] buffer;
}

void
GroundSurfaceProvider::putpixel(int x, int y)
{
  buffer[(x+y*width) * 4] = 0;
}

int 
GroundSurfaceProvider::get_pitch()
{
  return 4*get_width();
}

int
GroundSurfaceProvider::get_width() const
{
  return width;
}

int
GroundSurfaceProvider::get_height() const
{
  return height;
}

int 
GroundSurfaceProvider::get_no_sprs() const
{
  return 1;
}

EPixelFormat
GroundSurfaceProvider::get_pixel_format() const
{
  return RGBA8888;
}

CL_Palette*
GroundSurfaceProvider::get_palette() const
{
  return 0;
}

int
GroundSurfaceProvider::get_transcol() const
{
  return -1;
}

void*
GroundSurfaceProvider::get_surface_data() const
{
  return buffer;
}

void
GroundSurfaceProvider::lock()
{
  lock_refs++;
}

void
GroundSurfaceProvider::unlock()
{
  lock_refs--;
}

/* EOF */
