// Pingus - A free Lemmings clone
// Copyright (C) 1999 Ingo Ruhnke <grumbel@gmx.de>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

#ifndef PINGU_HH
#define PINGU_HH

#include "ColMap.hh"
#include "PinguAction.hh"
#include "PinguData.hh"
#include "PinguMap.hh"
#include "GameObj.hh"

class Pingu : GameObj
{
private:
  PinguAction* action;
  PinguAction* sec_action;
  PinguData data;
  int id;

  static int id_count;
  static ColMap* colmap;
  static PinguMap*  map;
  static CL_Surface* walker;
  static CL_Surface* faller;
  static CL_Surface* tumble;
  static CL_Font* font;

  AnimCounter walker_c;
  AnimCounter faller_c;
  AnimCounter tumble_c;
  int action_time;

public:
  Pingu(int x, int y);

  int  get_x();
  int  get_y();
  PinguEnvironment get_environment(); 
  bool is_alive(void);

  PinguStatus get_status(void);
  int get_id();
  void set_pos(int x, int y);
  void set_direction(Direction d);
  int  set_action(PinguAction*, int t = -2);
  PinguAction* get_action();
  int  rel_getpixel(int x, int y);
  void catch_pingu(Pingu* pingu);
  bool need_catch();
  
  void draw_offset(int x, int y, double s = 1.0);
  void let_move();

  bool is_over(int x, int y);

  static void set_colmap(ColMap* a);
  static void set_map(PinguMap*);
  static void load_data();
};

#endif

/* EOF */
